"""Client for the unofficial NBN API."""

from typing import Optional

from httpx import get


class NBN:
    """Interacts with NBN's unofficial API."""

    def __init__(self) -> None:
        """Sets base values required for API calls."""
        self.nbn_base_url = "https://places.nbnco.net.au/places"
        self.headers = {
            "Referer": "https://www2.nbnco.com.au/residential/learn/rollout-map"
        }

    def get_location_ids_from_lat_long(
        self, latitude: float, longitude: float
    ) -> Optional[dict]:
        """Returns NBN location ID's present near the lat & long combination.

        Location ID looks like LOC000000000000

        Args:
            latitude (float): Address latitude
            longitude (float): Address longitude

        Returns:
            dict: Locations & their ID's for addresses near the lat/long pairs

        Examples:
            >>> from nbnpy.nbn import NBN
            >>> nbn_client = NBN()
            >>> location_ids = nbn_client.get_location_ids_from_lat_long(
                    -37.80978345290123, 144.96518949578348
                )
            >>> bool(location_ids)
        """
        url = f"{self.nbn_base_url}/v1/nearby"

        params: dict = {
            "lat": latitude,
            "lng": longitude,
            "source": "website_rollout_map",
        }

        response = get(url=url, params=params, headers=self.headers)
        response_dict: dict = response.json()

        return response_dict

    def location_information(self, location_id: str) -> Optional[dict]:
        """Get connection type & details for given location.

        Args:
            location_id (str): NBN Location ID

        Returns:
            dict: Information regarding the connection details & type

        Examples:
            >>> from nbnpy.nbn import NBN
            >>> nbn_client = NBN()
            >>> location_info = nbn_client.location_information("LOC000175860243")
            >>> bool(location_info)
        """
        url = f"{self.nbn_base_url}/v2/details/{location_id}"

        params = {"source": "website_rollout_map"}

        response = get(url=url, params=params, headers=self.headers)
        response_dict: dict = response.json()

        return response_dict

    def get_location_ids_from_address(self, address: str) -> Optional[dict]:
        """Returns NBN location ID's present near the given address.

        Location ID looks like LOC000000000000

        Args:
            address (str): Location address

        Returns:
            dict: Locations & their ID's the address

        Examples:
            >>> from nbnpy.nbn import NBN
            >>> nbn_client = NBN()
            >>> location_ids = nbn_client.get_location_ids_from_address(
                    "1 Flinders Street, Melbourne VIC"
                )
            >>> bool(location_ids)
        """
        url = f"{self.nbn_base_url}/v1/autocomplete"

        params = {"query": address}

        response = get(url=url, params=params, headers=self.headers)
        response_dict: dict = response.json()

        return response_dict



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['nbnpy']

package_data = \
{'': ['*']}

install_requires = \
['httpx>=0.23.0,<0.24.0']

setup_kwargs = {
    'name': 'nbnpy',
    'version': '0.2.0',
    'description': 'Unofficial NBN API wrapper',
    'long_description': '# NBN-Py\n\n[![Code Hygiene](https://github.com/diabolical-ninja/nbnpy/actions/workflows/code_hygiene.yml/badge.svg)](https://github.com/diabolical-ninja/nbnpy/actions/workflows/code_hygiene.yml)\n[![codecov](https://codecov.io/gh/diabolical-ninja/nbn/branch/main/graph/badge.svg?token=hyTE4HlIxK)](https://codecov.io/gh/diabolical-ninja/nbn)\n![black codestyle](https://img.shields.io/badge/Code%20Style-Black-black)\n[![License](https://img.shields.io/badge/license-MIT-green)](./LICENSE)\n\n\n\nThis package provides an unofficial wrapper of the National Broadband Network\'s (NBN) API. It allows you to programatically lookup address\'s and examine connection details such as the connection type (FTTP, HFC, etc), service type, connection status and more.\n<br/><br/>\n**Disclaimer:** _This project is not affiliated with Nox, and not an official Nox plugin._\n\n\n## Installation\n\nInstall `nbnpy` from the Python Package Index:\n\n```console\n$ pip install nbn\n```\n\n## Requirements\n\n- Python 3.8+\n\n\n## Usage\n\nThis example gets the LocationID for an address then looks up the NBN connection details for it.\n```python\nimport pprint\nfrom nbnpy.nbn import NBN\n\nnbn_client = NBN()\nlocation_ids = nbn_client.get_location_ids_from_address("1 Flinders Street, Melbourne VIC")\n\n# The "get_location_ids_*" methods return a list of nearby locations\n# For the purpose of this example, the first result will suffice\nlocation_id = location_ids["suggestions"][0]["id"]\n\nlocation_info = nbn_client.location_information(location_id)\npprint.pprint(location_info)\n```\n\n## Building the Project\n\nThis package uses `poetry` and `nox` for package management and building. \n\nIf nox is not already installed, install it:\n```console\n$ pip install nox\n```\n\nRun everything including tests and documentation building\n```console\n$ nox\n\n# Or to run a specific stage:\n$ nox -s <stage name>, eg\n$ nox -s tests\n```\n\n\n## Issues\n\nIf you encounter any problems,\nplease [file an issue](https://github.com/diabolical-ninja/nbn/issues) along with a detailed description.\n',
    'author': 'Yass',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/diabolical-ninja/nbnpy',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
